/*
License: GPLv2, read more from COPYING

This file contains the functionality of JamMo Songs menu.
 */

#ifndef JAMMOSONGS_H_
#define JAMMOSONGS_H_

#include <meam/jammo-sequencer.h>
#include <meam/jammo-sample.h>

void start_jammosongs();
void end_jammosongs(TangleButton *tanglebutton, gpointer none);
gboolean add_song_to_list(char* loop_name, int number, guint32 user_id);
void record_voice_comment();
void stop_recording();
void rec_press_action(ClutterActor *song);
void review_selected_song(ClutterActor*);

#endif 
